@@ -22,7 +22,23 @@ KUBE_ROOT=$(dirname "${BASH_SOURCE}")/..
 cd "${KUBE_ROOT}"
 
 GOLINT=${GOLINT:-"golint"}
-PACKAGES=($(go list ./... | grep -v /vendor/ | grep -v vertical-pod-autoscaler/pkg/client | grep -v vertical-pod-autoscaler/pkg/apis))
+excluded_packages=(
+  '/vendor/'
+  'vertical-pod-autoscaler/pkg/client'
+  'cluster-autoscaler/cloudprovider/magnum/gophercloud'
+  'cluster-autoscaler/cloudprovider/digitalocean/godo'
+  'cluster-autoscaler/cloudprovider/exoscale/internal'
+  'cluster-autoscaler/cloudprovider/huaweicloud/huaweicloud-sdk-go-v3'
+  'cluster-autoscaler/cloudprovider/ionoscloud/ionos-cloud-sdk-go'
+)
+
+FIND_PACKAGES='go list ./... '
+for package in "${excluded_packages[@]}"; do
+     FIND_PACKAGES+="| grep -v ${package} "
+done
+
+PACKAGES=()
+mapfile -t PACKAGES < <(eval ${FIND_PACKAGES})
 bad_files=()
 for package in "${PACKAGES[@]}"; do
   out=$("${GOLINT}" -min_confidence=0.9 "${package}")
